# Vaga Link Python Library

The Vaga Link Python library provides convenient access to the Vaga Link API from applications written in the Python language. It includes a pre-defined set of classes for API resources that initialize themselves dynamically from API responses which makes it compatible with a wide range of versions of the Vaga Link API.

